@@ -6,7 +6,7 @@
 ############################################################################################################
 ####### BEGINNING OF DATA FOR THE MORPH.pm, RETRIEVE.pm, REPORT.pm AND Descenf.pm MODULES (TILL END) #######
 
-$mypath = "/home/luca/tryarea" ;# path of the directory in which you are going to work
+$mypath = "/home/luca/t" ;# path of the directory in which you are going to work
 
 @sweeps = ( [ [ 1, 2, 3, 4, 5, 6, 7 ] ] );
 #@sweeps = ( [ [ 1 ] ] );
@@ -26,10 +26,10 @@ $mypath = "/home/luca/tryarea" ;# path of the directory in which you are going t
 #@mediumiters = ( { 1 => 1 } ); # IN THIS ARRAY OF HASHES (DICTIONARIES) THE BASE ITERATION FOR EACH VARIABLES ARE SPECIFIED. 
 # IF LEFT UNSPECIFIED IT DEFAULTS TO THE MIDDLE ITERATION FOR EACH VARIABLE.  # IF LEFT UNSPECIFIED IT DEFAULTS TO THE CENTRAL VALUE FOR EACH GIVEN RANGE. 
 
-$file = "testmodish2";  # the root model directory.
+$file = "t";  # the root model directory.
 
 %dowhat = ( # This variables tells to the program what to do.
-morph => "y", # create cases for simulation?
+morph => "n", # create cases for simulation?
 simulate => "y", # simulate AND retrieve? THIS MUST BE "y" TO PERFORM BLOCK SEARCH.
 retrieve => "y",  # retrieve data? THIS MUST BE "y" TO PERFORM BLOCK SEARCH.
 report => "y",  # retrieve data? THIS MUST BE "y" TO PERFORM BLOCK SEARCH.
@@ -39,6 +39,10 @@ substitutenames => "n", # substitute names (convert) in non-filtered reports? (U
 filterconverted => "n", # filter already converted reports? (UNTESTED SINCE EARLY VERSIONS.)
 make3dtable => "n", # make table to be plotted in 3D? (UNTESTED SINCE EARLY VERSIONS.)
 overwrite_models => { 1 => "n" },
+inactivatemorph => "y",
+inactivatesim => "y",
+inactivateres => "y",
+incativateret => "n",
 actonexisting_models => { 1 => "y" },
 simtools => { 1 => "esp-r", 
 #2 => "energyplus" 
@@ -206,31 +210,31 @@ $reportdata{1} = # THERE IS A POINT-TO POINT CORRESPONDENCE TO THE ITEMS IN @ret
 		textpattern => "box" #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
 	},
 	{
-		reporttitle => "mar01-mar31-radent", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		reporttitle => "mar01-mar31", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
 		themereport => "radent", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
 		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
 		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
-		textpattern => " ", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+		textpattern => "#", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
 		#adhoclines => $vals{exportlines}{1} ,
-		afterlines => [ "1758-1805" ], # LINE TO RETRIEVE
+		afterlines => [ "341-388" ], # LINE TO RETRIEVE
 	},
 	{
-		reporttitle => "mar01-mar31-radabs", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		reporttitle => "mar01-mar31", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
 		themereport => "radabs", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
 		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
 		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
-		textpattern => " ", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+		textpattern => "#", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
 		#adhoclines => $vals{exportlines}{2} ,
-		afterlines => [ "1758-1805" ], # LINE TO RETRIEVE
+		afterlines => [ "341-388" ], # LINE TO RETRIEVE
 	},
 	{
-		reporttitle => "mar01-mar31-restemp", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		reporttitle => "mar01-mar31", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
 		themereport => "restemp", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
 		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
 		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
-		textpattern => " ", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+		textpattern => "#", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
 		#adhoclines => $vals{exportlines}{3} ,
-		afterlines => [ "1758-1805" ], # LINE TO RETRIEVE
+		afterlines => [ "341-388" ], # LINE TO RETRIEVE
 	},
 ]
 ],
@@ -287,31 +291,31 @@ $reportdata{1} = # THERE IS A POINT-TO POINT CORRESPONDENCE TO THE ITEMS IN @ret
 		textpattern => "box" #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
 	},
 	{
-		reporttitle => "jun01-jun31-radent", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		reporttitle => "jun01-jun31", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
 		themereport => "radent", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
 		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
 		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
-		textpattern => " ", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+		textpattern => "#", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
 		#adhoclines => $vals{exportlines}{1} ,
-		afterlines => [ "3966-4013" ], # LINE TO RETRIEVE
+		afterlines => [ "341-388" ], # LINE TO RETRIEVE
 	},
 	{
-		reporttitle => "jun01-jun31-radabs", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		reporttitle => "jun01-jun31", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
 		themereport => "radabs", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
 		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
 		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
-		textpattern => " ", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+		textpattern => "#", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
 		#adhoclines => $vals{exportlines}{2} ,
-		afterlines => [ "3966-4013" ], # LINE TO RETRIEVE
+		afterlines => [ "341-388" ], # LINE TO RETRIEVE
 	},
 	{
-		reporttitle => "jun01-jun31-restemp", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		reporttitle => "jun01-jun31", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
 		themereport => "restemp", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
 		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
 		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
-		textpattern => " ", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+		textpattern => "#", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
 		#adhoclines => $vals{exportlines}{3} ,
-		afterlines => [ "3966-4013" ], # LINE TO RETRIEVE
+		afterlines => [ "341-388" ], # LINE TO RETRIEVE
 	},
 ]
 ],
@@ -422,31 +426,31 @@ $reportdata{1} = # THERE IS A POINT-TO POINT CORRESPONDENCE TO THE ITEMS IN @ret
 		textpattern => "box" #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
 	},
 	{
-		reporttitle => "dec01-dec31-radent", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		reporttitle => "dec01-dec31", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
 		themereport => "radent", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
 		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
 		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
-		textpattern => " ", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+		textpattern => "#", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
 		#adhoclines => $vals{exportlines}{1} ,
-		afterlines => [ "8358-8405" ], # LINE TO RETRIEVE
+		afterlines => [ "341-388" ], # LINE TO RETRIEVE
 	},
 	{
-		reporttitle => "dec01-dec31-radabs", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		reporttitle => "dec01-dec31", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
 		themereport => "radabs", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
 		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
 		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
-		textpattern => " ", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+		textpattern => "#", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
 		#adhoclines => $vals{exportlines}{2} ,
-		afterlines => [ "8358-8405" ], # LINE TO RETRIEVE
+		afterlines => [ "341-388" ], # LINE TO RETRIEVE
 	},
 	{
-		reporttitle => "dec01-dec31-restemp", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
+		reporttitle => "dec01-dec31", #PERIODS TO REPORT IS THE "REPORT STATS" OPTIONS. 
 		themereport => "restemp", #STRING TO PUT IN THE RESULT FILE NAME TO RECOGNIZE IT. #PRE-MADE OPTIONS ARE "tempstats" and "loads". OTHER OPTIONS MUST BE ADDED BY MODIFYING THE SCRIPT.
 		semaphorego => "", # SEMAPHORE ON. STRING SIGNALLING THE ROW HAS ARRIVED AFTER WHICH E THE ROW WITH THE RESULTS IS ARRIVING. IF IT IS BLANK, IT IS IGNORED
 		semaphorestop => "", # SEMAPHORE OFF. STRING SIGNALLING THE ROW AFTER WHICH THE ONE THE ROW WITH THE RESULTS CAN ARRIVE NO MORE.
-		textpattern => " ", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
+		textpattern => "#", #STRING IN THE RESULT FILE SIGNALLING WHAT ROW HAS TO BE PICKED. THE TEXT RESULTS FILES HAS TO BE CHECKED TO DEDUCT THOSE.
 		#adhoclines => $vals{exportlines}{3} ,
-		afterlines => [ "8358-8405" ], # LINE TO RETRIEVE
+		afterlines => [ "341-388" ], # LINE TO RETRIEVE
 	},
 ]
 ],
@@ -611,7 +615,7 @@ $vals{1}{6}{applytype} = [ [ "rotate", "boxform.cfg", "boxform.cfg", "a" ] ] ; #
 # "change_groundreflectance", "genchange"
 $vals{1}{6}{rotate} = 
 [ 
-[ "n", [ 0, 90 ], "c", "a" ],
+[ "y", [ -135, 180 ], "c", "a" ],
 ];
 # [ # rotate obstructions? "y" o "n", # swing of rotation (HALF SWING, SWING MEASURED ON ONE SIDE WITH REGARDS TO THE MIDDLE) 
 # update radiation calculation with the "ish" module?  "b" for yes and "c" for no, continue, # vertex around which to rotate ]
@@ -627,18 +631,20 @@ $vals{1}{7}{change_groundreflectance} =
 [ 
 [ 0.20, [ 0, 0.60 ] ] # [ base value, [ low_change, high_change ] ]; OR: [ base value, half-range ];
 ];
-$vals{1}{7}{recalculateish} = [[ 3 ]]; 
-# recalculate the solar radiation? "y" or "n". This way the "ish" module is launched just at the end of a whole morphing operation, and not at every sub-operations composing it.
-$vals{1}{7}{use_modish} = 
-[
-[
-[ 1, "/zones/box.shd", 7 ]
-]
-];
-#$vals{1}{7}{export_toenergyplus} = [ [ "y", "sim", "retrieve", "milan.epw", [ "FullInteriorAndExterior", "FullInteriorAndExteriorWithReflections" ], 
-#[ "4;   !- Time Step in Hour", "1;   !- Time Step in Hour" ], [ "1, 1,   !- Begin Month", "2, 1,   !- Begin Month" ], 
-#[ "12,31,   !- End Month", " 2, 7,   !- End Month" ] ] ];
 
+$vals{1}{7}{todos} = 
+[ 
+[ 
+{ 
+	actions => [ "recalculateish" ], #possible actions: "recalculateish", "use_modish", constrain_geometry genprop constrain_obstructions constrain_net constrain_controls apply_constraints pin_obstructions recalculatenet recalculateish daylightcalc use_modish export_toenergyplus
+	parameters => [ 1, 2, 3, 4, 5, 6, 7 ],
+},
+] 
+];
+#possible actions: "recalculateish", "use_modish", constrain_geometry genprop constrain_obstructions constrain_net constrain_controls apply_constraints pin_obstructions recalculatenet recalculateish daylightcalc use_modish export_toenergyplus
+
+$vals{1}{7}{recalculateish} = [[ "y" ]]; 
+# recalculate the solar radiation? "y" or "n". This way the "ish" module is launched just at the end of a whole morphing operation, and not at every sub-operations composing it.
 
 ######################### PARAMETER 8. #############################
 
